[Openmp-commits] [PATCH] Fix some doxygen documentation

Jonathan Peyton jonathan.l.peyton at intel.com
Thu May 7 09:26:55 PDT 2015


Hi hfinkel,

This changes some text areas from saying Intel(R) OpenMP runtime library to LLVM OpenMP runtime library.  We will submit another patch to fix the README.txt file inside the runtime/ directory.

REPOSITORY
  rL LLVM

http://reviews.llvm.org/D9567

Files:
  runtime/doc/doxygen/config
  runtime/doc/doxygen/header.tex
  runtime/doc/doxygen/libomp_interface.h

Index: runtime/doc/doxygen/config
===================================================================
--- runtime/doc/doxygen/config
+++ runtime/doc/doxygen/config
@@ -26,7 +26,7 @@
 # identify the project. Note that if you do not use Doxywizard you need
 # to put quotes around the project name if it contains spaces.
 
-PROJECT_NAME           = "Intel® OpenMP* Runtime Library"
+PROJECT_NAME           = "LLVM OpenMP* Runtime Library"
 
 # The PROJECT_NUMBER tag can be used to enter a project or revision number.
 # This could be handy for archiving the generated documentation or
Index: runtime/doc/doxygen/header.tex
===================================================================
--- runtime/doc/doxygen/header.tex
+++ runtime/doc/doxygen/header.tex
@@ -51,39 +51,24 @@
 \begin{titlepage}
 \vspace*{7cm}
 \begin{center}
-{\Large Intel\textsuperscript{\textregistered}  OpenMP\textsuperscript{*} Runtime Library }\\
+{\Large LLVM OpenMP\textsuperscript{*} Runtime Library }\\
 \vspace*{1cm}
 {\large Generated by Doxygen $doxygenversion }\\
 \vspace*{0.5cm}
 {\small $datetime }\\
 \end{center}
 \end{titlepage}
 
-{\bf FTC Optimization Notice}
-\\
-Intel's compilers may or may not optimize to the same degree for non-Intel microprocessors for
-optimizations that are not unique to Intel microprocessors. These optimizations include SSE2,
-SSE3, and SSE3 instruction sets and other optimizations. Intel does not guarantee the
-availability, functionality, or effectiveness of any optimization on microprocessors not
-manufactured by Intel.
-
-Microprocessor-dependent optimizations in this product are intended for use with Intel
-microprocessors. Certain optimizations not specific to Intel microarchitecture are reserved for
-Intel microprocessors. Please refer to the applicable product User and Reference Guides for
-more information regarding the specific instruction sets covered by this notice.
-
-Notice revision \#20110804
-
 {\bf Trademarks}
-\\
+The OpenMP name and the OpenMP logo are registered trademarks of the OpenMP Architecture Review Board.
+
 Intel, Xeon, and Intel Xeon Phi are trademarks of Intel Corporation in the U.S. and/or other countries.
 
+This document is Copyright \textcopyright~\the\year the LLVM team. It is
+subject to the same license terms as the LLVM OpenMP runtime.
+ 
 \textsuperscript{*} Other names and brands may be claimed as the property of others.
 
-The OpenMP name and the OpenMP logo are registered trademarks of the OpenMP Architecture Review Board.
-
-This document is Copyright \textcopyright 2013, Intel Corporation. All rights reserved. 
- 
 \clearemptydoublepage
 \pagenumbering{roman}
 \tableofcontents
Index: runtime/doc/doxygen/libomp_interface.h
===================================================================
--- runtime/doc/doxygen/libomp_interface.h
+++ runtime/doc/doxygen/libomp_interface.h
@@ -12,11 +12,11 @@
 //===----------------------------------------------------------------------===//
 
 
 /*! @mainpage Intel®  OpenMP* Runtime Library Interface
 @section sec_intro Introduction
 
 This document describes the interface provided by the
-Intel® OpenMP\other runtime library to the compiler.
+LLVM  OpenMP\other runtime library to the compiler.
 Routines that are directly called as simple functions by user code are
 not currently described here, since their definition is in the OpenMP
 specification available from http://openmp.org

EMAIL PREFERENCES
  http://reviews.llvm.org/settings/panel/emailpreferences/
-------------- next part --------------
@@ -12,11 +12,11 @@
 
 
-/*! @mainpage Intel®  OpenMP* Runtime Library Interface
+/*! @mainpage LLVM  OpenMP* Runtime Library Interface
 @section sec_intro Introduction
 
A non-text attachment was scrubbed...
Name: D9567.25196.patch
Type: text/x-patch
Size: 3532 bytes
Desc: not available
URL: <http://lists.llvm.org/pipermail/openmp-commits/attachments/20150507/258cc77f/attachment.bin>


More information about the Openmp-commits mailing list